@@ -2486,7 +2486,170 @@ def heatmap_compNvalid(df, outfilename=None, daterange=None, hospitals='IHA'):
 ###########################################################################################################################################################
 ###########################################################################################################################################################
 
+def Visualization_1time(df,invalid='ok',title='default',show=True,savefilepath=None,gridlines=True,cyanline=True):
+    '''
+    Description
+    -----------
+    Returns a heatmap of completion for each element congregated visits within a facility.
+    
+    Input
+    ----------
+    df: dataframe, required
+        pandas dataframe output of NSSP_Element_Grabber() function.
+        filter on priority BEFORE inputting into function
+        NEEDS to contain visit number, visit mrn, facility name
+        
+    invalid: str, optional (default = 'ok')  
+        if 'ok', count non-missing,invalid element entries as True for completion
+        if 'bad', count non-missing,invalid element entries as False for completion
 
+    title: str, optional (default = 'default')   
+        If you want, create your own title
+        
+    show: bool, optional (default = True)
+        displays plot
+        
+    savefilepath: str, optional (default = None)
+        specify path to save the .html interactive heatmap to
+        
+        
+    gridlines: bool, optional (default = True)
+        Makes black gridlines to seperate cells in heatmap
+        
+    cyanline: bool, optional (default = True)
+        Makes a cyan line seperating priority 1 and 2 elements
+    
+    
+    Output
+    ----------
+    Dataframe that populates heatmap
+    Interactive hoverover heatmap (options to save file)
+    
+    Requirements
+    -------------
+    from ADTdq import *
+    '''
+    
+    # Get validity report
+    validity_repo = validity_and_completeness_report(df)[1]
+
+    find_maxes = validity_repo.groupby('VisInd').max()
+    
+    ######################################################################
+    # Specify elements as valid or invalid
+    ######################################################################
+    
+    find_maxes = find_maxes.replace(0,False)
+    find_maxes = find_maxes.replace(2,True)
+
+    if (invalid == 'ok'):
+        find_maxes = find_maxes.replace(1,True)
+        
+    elif (invalid == 'bad'):
+        find_maxes = find_maxes.replace(1,False)
+    
+    else:
+        raise ValueError('Please input valid entry for "invalid = " argument. ("ok" or "bad")')
+    
+
+    ###############################################################################
+    
+    base = (find_maxes.groupby(['FacName']).sum() / find_maxes.groupby(['FacName']).count() * 100).round(2)
+    
+    ###############################################################################
+    # Find out where the blue line should go to seperate priority 1 and 2
+
+
+    all_elements = list_elements(include_priority=True)
+    included_elements = all_elements[all_elements['Processed Column'].isin(base.columns)].sort_values('Processed Column')
+    X =  base.columns.sort_values()
+    Y = included_elements['Priority']
+    ordered = np.array([x for _, x in sorted(zip(Y,X), key=lambda pair: pair[0])])
+    pri1_sum = (included_elements['Priority'] == 1.0).sum()
+    base = base[ordered]
+    
+    
+    
+    ###############################################################################
+
+    # Create a list of lists that describes all hoverover text
+    colnames = [list(base.columns)]*len(base)
+    hover=[]
+    for x in range(len(np.array(base))):
+        hover.append(['Facility: '+str(base.index[x])+'<br>'+'Element: '+str(k)+'<br>'+'Completion: ' + str(i) + '%' 
+                          for i, k in zip(np.array(base)[x], colnames[x])])
+
+    #######################################################################
+
+    # Make heatmap elements as simple variables
+    heat = np.array(base)
+    x = np.array(base.columns)
+    y = np.array(base.index)
+
+    #######################################################################
+
+
+    # Create a large heatmap with descriptive title
+    
+    if (title != 'default'):
+        layout_heatmap = go.Layout(
+            title=(title),
+            title_x=0.5,
+            xaxis=dict(title='NSSP Priority Element'), 
+            yaxis=dict(title='Facility', dtick=1),
+            autosize=False,
+            width=1500,
+            height=1000
+        )
+        
+    else:
+        layout_heatmap = go.Layout(
+            title=('NSSP Priority Element Completeness Report'),
+            title_x=0.5,
+            xaxis=dict(title='NSSP Priority Element'), 
+            yaxis=dict(title='Facility', dtick=1),
+            autosize=False,
+            width=1500,
+            height=1000
+        )
+        
+    
+    # Make one heatmap with positive value annotations in green (see font_colors arg)
+    ff_fig1 = ff.create_annotated_heatmap(heat,x=list(x), y=list(y),hoverinfo='text',colorscale='rdylgn',
+                                     text=hover,showscale = True,
+                                         zmin=0,zmax=100)
+
+    # Append out heatmap, its annotations, and a colorbar to our figure
+    fig  = go.FigureWidget(ff_fig1)
+    fig.layout=layout_heatmap
+    fig.data[0].colorbar = dict(title='Percent Complete', titleside = 'right')
+
+
+    if (gridlines == True):
+    
+        # Horizontal Lines LEFT plot
+        for i in np.arange(0,len(base.index)+1):
+            fig.add_shape(type="line", x0=0-0.5, y0=i-0.5, x1=len(base.columns)-0.5, y1=i-0.5,
+                        line=dict(color="black",width=2))
+
+        # Vertical lines LEFT plot
+        for i in np.arange(0,len(base.columns)+1):
+            fig.add_shape(type="line", x0=i-0.5, y0=0-0.5, x1=i-0.5, y1=len(base.index)-0.5,
+                    line=dict(color="black",width=3))
+
+    if (cyanline == True):
+        fig.add_shape(type="line", x0=pri1_sum-0.5, y0=0-0.5, x1=pri1_sum-0.5, y1=len(base.index)-0.5,
+                                        line=dict(color="cyan",width=3))
+
+
+    if (show == True):
+        iplot(fig)
+        
+    if (savefilepath != None):
+        fig.write_html(savefilepath)
+        
+        
+    return base
 
 
 
